#
# spec file for package python-parsel
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-parsel
Version:        1.9.1
Release:        1.3
Summary:        Library to extract data from HTML and XML using XPath and CSS selectors
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/scrapy/parsel
Source:         https://files.pythonhosted.org/packages/source/p/parsel/parsel-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module cssselect >= 1.2.0}
BuildRequires:  %{python_module jmespath}
BuildRequires:  %{python_module lxml}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module typing-extensions}
BuildRequires:  %{python_module w3lib >= 1.19.0}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-cssselect >= 1.2.0
Requires:       python-jmespath
Requires:       python-lxml
Requires:       python-typing-extensions
Requires:       python-w3lib >= 1.19.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Parsel is a library to extract data from HTML and XML using XPath and CSS
selectors.

%prep
%autosetup -p1 -n parsel-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/parsel
%{python_sitelib}/parsel-%{version}.dist-info

%changelog
* Sat Apr 27 2024 Dirk Müller <dmueller@suse.com>
- update to 1.9.1:
  * Removed the dependency on ``pytest-runner``.
  * Removed the obsolete ``Makefile``.
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 1.9.0:
  * Now requires ``cssselect >= 1.2.0`` (this minimum version was
    required since 1.8.0 but that wasn't properly recorded)
  * Removed support for Python 3.7
  * Added support for Python 3.12 and PyPy 3.10
  * Fixed an exception when calling ``__str__`` or `__repr__`` on
    some JSON selectors
  * Code formatted with ``black``
  * CI fixes and improvements
* Wed Dec 20 2023 Dirk Müller <dmueller@suse.com>
- update to 1.8.1:
  * Remove a Sphinx reference from NEWS to fix the PyPI
    description
  * Add support for JMESPath: you can now create a selector for a
    JSON document and call ``Selector.jmespath()``.
  * Selectors can now be constructed from ``bytes`` (using the
    ``body`` and ``encoding`` arguments) instead of ``str``
    (using the ``text`` argument), so that there is no internal
    conversion from ``str`` to ``bytes`` and the memory
    usage is lower.
  * Typing improvements
  * The ``pkg_resources`` module (which was absent from the
    requirements) is no longer used
  * New requirements:
  * ``jmespath``
  * ``typing_extensions`` (on Python 3.7)
* Sat Jan  7 2023 Dirk Müller <dmueller@suse.com>
- update to 1.7.0:
  * Add PEP 561-style type information
  * Support for Python 2.7, 3.5 and 3.6 is removed
  * Support for Python 3.9-3.11 is added
  * Very large documents (with deep nesting or long tag content) can now be
  parsed, and ``Selector`` now takes a new argument ``huge_tree`` to disable
  this
  * Support for new features of cssselect 1.2.0 is added
  * The ``Selector.remove()`` and ``SelectorList.remove()`` methods are
  deprecated and replaced with the new ``Selector.drop()`` and
  ``SelectorList.drop()`` methods which don't delete text after the dropped
  elements when used in the HTML mode.
- drop python-parsel-drop-python-2.patch (upstream)
* Mon Oct 17 2022 pgajdos@suse.com
- added patches
  fix https://github.com/scrapy/parsel/commit/ddb3708b9a191ca02bd20e621f43c68cc92f5d6b
  + python-parsel-drop-python-2.patch
* Wed Aug 25 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.6.0:
  * Python 3.4 is no longer supported
  * New `Selector.remove()` and `SelectorList.remove()` methods to
    remove selected elements from the parsed document tree
  * Improvements to error reporting, test coverage and documentation,
    and code cleanup
* Mon Mar 15 2021 Dirk Müller <dmueller@suse.com>
- fix build requires syntax error on expanding multiple python flavors
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Wed Sep 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.5.2:
  * ``Selector.remove_namespaces`` received a significant performance improvement
  * The value of ``data`` within the printable representation of a selector
    (``repr(selector)``) now ends in ``...`` when truncated, to make the
    truncation obvious.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri Nov 16 2018 Todd R <toddrme2178@gmail.com>
- Update to version 1.5.1 (2018-10-25)
  * ``has-class`` XPath function handles newlines and other separators
    in class names properly;
  * fixed parsing of HTML documents with null bytes;
  * documentation improvements;
  * Python 3.7 tests are run on CI; other test improvements.
- Update to version 1.5.0 (2018-07-04)
  * New ``Selector.attrib`` and ``SelectorList.attrib`` properties which make
    it easier to get attributes of HTML elements.
  * CSS selectors became faster: compilation results are cached
    (LRU cache is used for ``css2xpath``), so there is
    less overhead when the same CSS expression is used several times.
  * ``.get()`` and ``.getall()`` selector methods are documented and recommended
    over ``.extract_first()`` and ``.extract()``.
  * Various documentation tweaks and improvements.
* Fri Apr  6 2018 mpluskal@suse.com
- Update to version 1.4.0:
  * has-class XPath extension function;
  * parsel.xpathfuncs.set_xpathfunc is a simplified way to register
    XPath extensions;
  * Selector.remove_namespaces now removes namespace declarations;
  * Python 3.3 support is dropped;
  * make htmlview command for easier Parsel docs development.
* Thu Dec 21 2017 mpluskal@suse.com
- Update to version 1.2.0:
  * Add get() and getall() methods as aliases for extract_first and
    extract respectively
  * Add default value parameter to SelectorList.re_first method
  * Add Selector.re_first method
  * Bug fix: detect None result from lxml parsing and fallback with
    an empty document
  * Rearrange XML/HTML examples in the selectors usage docs
- Convert to singlespec
* Thu Jun  2 2016 jacobwinski@gmail.com
- Initial package build.
